from django.contrib.auth import login, get_user_model
from django.contrib.sessions.models import Session
from swampdragon.connections.sockjs_connection import DjangoSubscriberConnection


class HttpDataConnection(DjangoSubscriberConnection):
    def __init__(self, session):
        self._user = None
        super(HttpDataConnection, self).__init__(session)

    def get_user(self):
        try:
            if self._user is not None:
                return self._user
            morsel = self.session.conn_info.cookies.get('sessionid')
            session = Session.objects.get(session_key=morsel.value)
            decoded_session = session.get_decoded()
            self._user = get_user_model().objects.get(pk=decoded_session['_auth_user_id'])
        except:
            self._user = None
        return self._user

    @property
    def user(self):
        return self.get_user()



import os
from setuptools import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name="SwampDragon-auth",
    version="0.1.0",
    author="Jonas Hagstedt",
    author_email="hagstedt@gmail.com",
    description=("Access signed in django users in routers"),
    license="BSD",
    keywords="SwampDragon, SwampDragon-auth, auth, authentication",
    url = "https://github.com/jonashagstedt/swampdragon-auth",
    packages=['swampdragon_auth', ],
    include_package_data=True,
    long_description=read('README.md'),
    install_requires=[
        "SwampDragon"
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
    ],
)
